# **Compress** [![](https://gitee.com/tyoui/logo/raw/master/logo/photolog.png)][1]

## 关于压缩包模块集合
[![](https://img.shields.io/badge/个人网站-jtyoui-yellow.com.svg)][1]
[![](https://img.shields.io/badge/Python-3.7-green.svg)]()
[![](https://img.shields.io/badge/BlogWeb-Tyoui-bule.svg)][1]
[![](https://img.shields.io/badge/Email-jtyoui@qq.com-red.svg)]()
[![](https://img.shields.io/badge/压缩包-compress-black.svg)]()


#### 安装
    pip install jtyoui

***
[1]: https://blog.jtyoui.com